==> unityads-4.7.5-sources.jar: com/yodo1/mas/mediation/unityads/Yodo1MasUnityAdsRewardAdapter.java <==
package com.yodo1.mas.mediation.unityads;

import android.app.Activity;
import android.text.TextUtils;
import android.util.Log;

import androidx.annotation.NonNull;

import com.unity3d.ads.IUnityAdsLoadListener;
import com.unity3d.ads.IUnityAdsShowListener;
import com.unity3d.ads.UnityAds;
import com.unity3d.ads.UnityAdsShowOptions;
import com.yodo1.mas.error.Yodo1MasError;
import com.yodo1.mas.mediation.Yodo1MasAdapterBase;
import com.yodo1.mas.reward.Yodo1MasRewardAdapterBase;

import java.util.List;

public class Yodo1MasUnityAdsRewardAdapter extends Yodo1MasRewardAdapterBase {

    public Yodo1MasUnityAdsRewardAdapter(List<Yodo1MasAdapterBase.AdId> unitIds) {
        super(unitIds);
    }

    @Override
    public boolean isRewardAdLoaded() {
        String adId = getAdUnitId(false);
        return !TextUtils.isEmpty(adId) && super.isRewardAdLoaded();
    }

    @Override
    public void loadRewardAdvert(@NonNull Activity activity) {
        super.loadRewardAdvert(activity);
        String adId = getAdUnitId(false);
        if (TextUtils.isEmpty(adId)) return;

        if (rewardStatus == Yodo1MasAdapterBase.AdvertStatus.LOADING) return;
        String message = "method: loadRewardAdvert, loading reward ad...";
        Log.d(TAG, message);

        rewardStatus = Yodo1MasAdapterBase.AdvertStatus.LOADING;
        UnityAds.load(adId, loadListener);
    }

    @Override
    public void showRewardAdvertFromActivity(@NonNull Activity activity) {
        super.showRewardAdvertFromActivity(activity);
        if (isRewardAdLoaded()) {
            String message = "method: showRewardAdvert, show reward ad...";
            Log.d(TAG, message);
            String adId = getAdUnitId(false);
            UnityAds.show(activity, adId, new UnityAdsShowOptions(), showListener);
        }
    }

    private final IUnityAdsLoadListener loadListener = new IUnityAdsLoadListener() {
        @Override
        public void onUnityAdsAdLoaded(String placementId) {
            String message = "method: onUnityAdsAdLoaded, placementId: " + placementId + "}";
            Log.d(TAG, message);
            callbackLoad();
        }

        @Override
        public void onUnityAdsFailedToLoad(String placementId, UnityAds.UnityAdsLoadError adError, String adMessage) {
            String msg = "method: onUnityAdsFailedToLoad, placementId: " + placementId + " error: " + adError.toString() + " message: " + adMessage + "}";
            Log.d(TAG, msg);
            Yodo1MasError error = new Yodo1MasError(Yodo1MasError.CODE_ADVERT_LOAD_FAIL, TAG + ":{" + adMessage + "}");
            callbackError(error, adError.ordinal(), adMessage);
        }
    };

    private final IUnityAdsShowListener showListener = new IUnityAdsShowListener() {
        @Override
        public void onUnityAdsShowFailure(String placementId, UnityAds.UnityAdsShowError adError, String adMessage) {
            String msg = "method: onUnityAdsShowFailure, placementId: " + placementId + ", error: " + adError.toString() + ", message: " + adMessage + "}";
            Log.d(TAG, msg);
            Yodo1MasError error = new Yodo1MasError(Yodo1MasError.CODE_ADVERT_SHOW_FAIL, TAG + ":{" + msg + "}");
            callbackError(error, adError.ordinal(), adMessage);
        }

        @Override
        public void onUnityAdsShowStart(String placementId) {
            String message = "method: onUnityAdsShowStart, placementId: " + placementId + "}";
            Log.d(TAG, message);
            callbackOpen();
        }

        @Override
        public void onUnityAdsShowComplete(String placementId, UnityAds.UnityAdsShowCompletionState state) {
            String message = "method: onUnityAdsShowComplete, placementId: " + placementId + "}";
            Log.d(TAG, message);

            if (state == UnityAds.UnityAdsShowCompletionState.COMPLETED) {
                callbackEarned();
            }
            callbackClose();
        }

        @Override
        public void onUnityAdsShowClick(String placementId) {
            String message = "method: onUnityAdsShowClick, placementId: " + placementId + "}";
            Log.d(TAG, message);
        }
    };
}

==> unityads-4.8.2-sources.jar: com/yodo1/mas/mediation/unityads/Yodo1MasUnityAdsRewardAdapter.java <==
package com.yodo1.mas.mediation.unityads;

import android.app.Activity;
import android.text.TextUtils;

import androidx.annotation.NonNull;

import com.unity3d.ads.IUnityAdsLoadListener;
import com.unity3d.ads.IUnityAdsShowListener;
import com.unity3d.ads.UnityAds;
import com.unity3d.ads.UnityAdsShowOptions;
import com.yodo1.mas.Yodo1MasLog;
import com.yodo1.mas.error.Yodo1MasError;
import com.yodo1.mas.mediation.Yodo1MasAdapterBase;
import com.yodo1.mas.reward.Yodo1MasRewardAdapterBase;

import java.util.List;

public class Yodo1MasUnityAdsRewardAdapter extends Yodo1MasRewardAdapterBase {

    public Yodo1MasUnityAdsRewardAdapter(List<Yodo1MasAdapterBase.AdId> unitIds) {
        super(unitIds);
    }

    @Override
    public boolean isRewardAdLoaded() {
        String adId = getAdUnitId(false);
        return !TextUtils.isEmpty(adId) && super.isRewardAdLoaded();
    }

    @Override
    public void loadRewardAdvert(@NonNull Activity activity) {
        super.loadRewardAdvert(activity);
        String adId = getAdUnitId(false);
        if (TextUtils.isEmpty(adId)) return;

        if (rewardStatus == Yodo1MasAdapterBase.AdvertStatus.LOADING) return;
        String message = "method: loadRewardAdvert, loading reward ad...";
        Yodo1MasLog.v(TAG, message);

        rewardStatus = Yodo1MasAdapterBase.AdvertStatus.LOADING;
        UnityAds.load(adId, loadListener);
    }

    @Override
    public void showRewardAdvertFromActivity(@NonNull Activity activity) {
        super.showRewardAdvertFromActivity(activity);
        if (isRewardAdLoaded()) {
            String message = "method: showRewardAdvert, show reward ad...";
            Yodo1MasLog.v(TAG, message);
            String adId = getAdUnitId(false);
            UnityAds.show(activity, adId, new UnityAdsShowOptions(), showListener);
        }
    }

    private final IUnityAdsLoadListener loadListener = new IUnityAdsLoadListener() {
        @Override
        public void onUnityAdsAdLoaded(String placementId) {
            String message = "method: onUnityAdsAdLoaded, placementId: " + placementId + "}";
            Yodo1MasLog.v(TAG, message);
            callbackLoad();
        }

        @Override
        public void onUnityAdsFailedToLoad(String placementId, UnityAds.UnityAdsLoadError adError, String adMessage) {
            String msg = "method: onUnityAdsFailedToLoad, placementId: " + placementId + " error: " + adError.toString() + " message: " + adMessage + "}";
            Yodo1MasLog.v(TAG, msg);
            Yodo1MasError error = new Yodo1MasError(Yodo1MasError.CODE_ADVERT_LOAD_FAIL, TAG + ":{" + adMessage + "}");
            callbackError(error, adError.ordinal(), adMessage);
        }
    };

    private final IUnityAdsShowListener showListener = new IUnityAdsShowListener() {
        @Override
        public void onUnityAdsShowFailure(String placementId, UnityAds.UnityAdsShowError adError, String adMessage) {
            String msg = "method: onUnityAdsShowFailure, placementId: " + placementId + ", error: " + adError.toString() + ", message: " + adMessage + "}";
            Yodo1MasLog.v(TAG, msg);
            Yodo1MasError error = new Yodo1MasError(Yodo1MasError.CODE_ADVERT_SHOW_FAIL, TAG + ":{" + msg + "}");
            callbackError(error, adError.ordinal(), adMessage);
        }

        @Override
        public void onUnityAdsShowStart(String placementId) {
            String message = "method: onUnityAdsShowStart, placementId: " + placementId + "}";
            Yodo1MasLog.v(TAG, message);
            callbackOpen();
        }

        @Override
        public void onUnityAdsShowComplete(String placementId, UnityAds.UnityAdsShowCompletionState state) {
            String message = "method: onUnityAdsShowComplete, placementId: " + placementId + "}";
            Yodo1MasLog.v(TAG, message);

            if (state == UnityAds.UnityAdsShowCompletionState.COMPLETED) {
                callbackEarned();
            }
            callbackClose();
        }

        @Override
        public void onUnityAdsShowClick(String placementId) {
            String message = "method: onUnityAdsShowClick, placementId: " + placementId + "}";
            Yodo1MasLog.v(TAG, message);
        }
    };
}
